Competitors — SoL 3 developers documentation

### Navigation

- index
- modules |
- next |
- previous |
- Dev's documentation »
- SoL modules »
- `sol.models` – SQLAlchemy modelization »

# Competitors

class `sol.models.competitor.` `Competitor`(**kwargs)

  A single competitor in a game.

  A competitor may be a single person or a team of up to four players, that participate to a given tourney. On each competitor this table keeps the points, the netscore and his bucholz, as well as the final prize. To disambiguate the ranking it maintains also a totscore, the total number of pocketed carrommen summing up competitor’ scores in all played games.

  `bucholz`

    Weight of the opponents (sum of opponents’ points and netscore).

  `caption`(html=None, localized=True, player_caption=None)

    A description of the competitor, made up with the name of each player.

  `description`

    A description of the competitor, made up with the name of each player.

  `idcompetitor`

    Primary key.

  `idplayer1`

    First player’s ID.

  `idplayer2`

    Second player’s ID.

  `idplayer3`

    Third player’s ID.

  `idplayer4`

    Fourth player’s ID.

  `idtourney`

    Subscribed tourney’s ID.

  `netscore`

    Net score (sum of carrommen difference in each match).

  `player1`

    First player.

  `player2`

    Second player.

  `player3`

    Third player.

  `player4`

    Fourth player.

  `points`

    Points (number of wins * 2 + number of draws).

  `prize`

    Final prize.

  `retired`

    A competitor may stop playing in the middle of the tourney.

  `serialize`(serializer)

    Reduce a single competitor to a simple dictionary

  `totscore`

    Total score (sum of carrommen in each match).

### Navigation

- index
- modules |
- next |
- previous |
- Dev's documentation »
- SoL modules »
- `sol.models` – SQLAlchemy modelization »